<?php

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */
function wpsg_optionsframework_option_name() {
    $wpsg_optionsframework_settings = get_option('wpsg_optionsframework');
    $wpsg_optionsframework_settings['id'] = WPSG_OPTIONS_FRAMEWORK_TAG;
    update_option('wpsg_optionsframework', $wpsg_optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */
function wpsg_optionsframework_options() {
    $colorboxpath = WPSIMPLEGALLERY_URL . 'colorbox/';
    $options = array();

    $options[] = array("name" => "Basic Settings",
        "type" => "heading");

    $options[] = array("name" => "Thumbnail Width",
        "desc" => "Thumbnail width (changing this will require thumbnails to be regenerated, this plugin will help: <a href='http://wordpress.org/extend/plugins/regenerate-thumbnails/' target='_blank'>Regenerate Thumbnails</a>).",
        "id" => "wpsimplegallery_thumb_width",
        "std" => "100",
        "class" => "mini",
        "type" => "text");
    $options[] = array("name" => "Thumbnail Height",
        "desc" => "Thumbnail height (changing this will require thumbnails to be regenerated, this plugin will help: <a href='http://wordpress.org/extend/plugins/regenerate-thumbnails/' target='_blank'>Regenerate Thumbnails</a>).",
        "id" => "wpsimplegallery_thumb_height",
        "std" => "100",
        "class" => "mini",
        "type" => "text");

    $options[] = array("name" => "Content Filter Priority",
        "desc" => "Used to specify the order execution. Lower numbers correspond with earlier execution, so set it to 1 to make it appear before all other plugins on content pages.",
        "id" => "wpsimplegallery_filter_priority",
        "std" => "10",
        "class" => "mini",
        "type" => "text");

    $post_types_default = array('post' => '1', 'page' => '1');
    $post_types = get_post_types();

    unset($post_types['attachment']);
    unset($post_types['revision']);
    unset($post_types['nav_menu_item']);
    unset($post_types['mediapage']);

    $options[] = array("name" => "Post Types",
        "desc" => "What post types do you want to have galleries enabled",
        "id" => "wpsimplegallery_post_types",
        "std" => $post_types_default,
        "options" => $post_types,
        "type" => "multicheck");

    $options[] = array("name" => "Show on single posts only",
        "desc" => "This will stop galleries from showing when more than one post is being shown.",
        "id" => "single_only",
        "std" => "1",
        "type" => "checkbox");

    
    
    $options[] = array("name" => "Please Donate",
        "desc" => "Alot of time and effort went into making this plugin, all donations are hugely appreciated.",
        "url" => "http://maca134.co.uk/blog/wp-simple-galleries/",
        "type" => "donate");


    $options[] = array("name" => "Colorbox Settings",
        "type" => "heading");

    $options[] = array("name" => "Use Colorbox",
        "desc" => "Check to use colorbox. Sometimes it can conflict with other plugins such as Shopp.",
        "id" => "use_colorbox",
        "std" => "1",
        "type" => "checkbox");

    $options[] = array("name" => "Colorbox Theme",
        "id" => "wpsimplegallery_colorbox_theme",
        "std" => "theme1",
        "type" => "images",
        "options" => array(
            'theme1' => $colorboxpath . 'themes/theme1/style.png',
            'theme2' => $colorboxpath . 'themes/theme2/style.png',
            'theme3' => $colorboxpath . 'themes/theme3/style.png',
            'theme4' => $colorboxpath . 'themes/theme4/style.png',
            'theme5' => $colorboxpath . 'themes/theme5/style.png'
        )
    );

    $options[] = array("name" => "Please Donate",
        "desc" => "Alot of time and effort went into making this plugin, all donations are hugely appreciated.",
        "url" => "http://maca134.co.uk/blog/wp-simple-galleries/",
        "type" => "donate");

    return $options;
}